@@ -4,8 +4,8 @@ from dataclasses import dataclass
 from mlbstatsapi.models.teams import Team
 from mlbstatsapi.models.people import Person
 
-@dataclass(kw_only=True)
-class Award():
+@dataclass(kw_only=True, repr=False)
+class Award:
     """
     This class represents an award object
 
@@ -23,6 +23,8 @@ class Award():
         Team award was to/ Player is from
     player : Person
         Person award is for
+    votes : int None
+        Any votes associated with award
     notes : str  None
         Any notes associated with award
     """
@@ -33,8 +35,13 @@ class Award():
     season: str
     team: Union[Team, dict]
     player: Union[Person, dict]
+    votes: Optional[int] = None
     notes: Optional[str] = None
 
     def __post_init__(self):
         self.team = Team(**self.team)
-        self.player = Person(**self.player)
\ No newline at end of file
+        self.player = Person(**self.player)
+
+    def __repr__(self) -> str:
+        kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None and value]
+        return "{}({})".format(type(self).__name__, ", ".join(kws))
\ No newline at end of file
