@@ -12,11 +12,11 @@ from mlbstatsapi.models.data import (
     PlayDetails
 )
 from .stats import (
-    Stat,
     Sabermetrics,
-    ExpectedStatistics
+    ExpectedStatistics,
+    Split
 )
-@dataclass
+@dataclass(repr=False)
 class AdvancedHittingSplit:
     """
     A class to represent a advanced hitting statistics
@@ -128,8 +128,11 @@ class AdvancedHittingSplit:
     groundhits: Optional[int] = None
     linehits: Optional[int] = None
 
+    def __repr__(self) -> str:
+        kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None]
+        return "{}({})".format(type(self).__name__, ", ".join(kws))
 
-@dataclass
+@dataclass(repr=False)
 class SimpleHittingSplit:
     """
     A class to represent a simple hitting statistics
@@ -242,8 +245,12 @@ class SimpleHittingSplit:
     catchersinterference: Optional[int] = None
     atbatsperhomerun: Optional[int] = None
 
-@dataclass(kw_only=True)
-class HittingWinLoss(Stat):
+    def __repr__(self) -> str:
+        kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None]
+        return "{}({})".format(type(self).__name__, ", ".join(kws))
+
+@dataclass(kw_only=True, repr=False)
+class HittingWinLoss(Split):
     """
     A class to represent a hitting winLoss statistic
 
@@ -260,10 +267,11 @@ class HittingWinLoss(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingWinLossPlayoffs(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingWinLossPlayoffs(Split):
     """
     A class to represent a hitting winLossPlayoffs statistic
 
@@ -280,10 +288,11 @@ class HittingWinLossPlayoffs(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingHomeAndAway(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingHomeAndAway(Split):
     """
     A class to represent a hitting homeAndAway statistic
 
@@ -300,10 +309,11 @@ class HittingHomeAndAway(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingHomeAndAwayPlayoffs(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingHomeAndAwayPlayoffs(Split):
     """
     A class to represent a hitting homeAndAway Playoff statistic
 
@@ -320,9 +330,10 @@ class HittingHomeAndAwayPlayoffs(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingCareer(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingCareer(Split):
     """
     A class to represent a hitting career, careerRegularSeason or careerPlayoffs statistic
 
@@ -335,10 +346,12 @@ class HittingCareer(Stat):
     stat: Union[SimpleHittingSplit, dict]
     
     def __post_init__(self):
+        super().__post_init__()
         self.stat = SimpleHittingSplit(**self.stat)
 
-@dataclass(kw_only=True)
-class HittingSeason(Stat):
+
+@dataclass(kw_only=True, repr=False)
+class HittingSeason(Split):
     """
     A class to represent a hitting season statistic
 
@@ -351,10 +364,11 @@ class HittingSeason(Stat):
     stat: Union[SimpleHittingSplit, dict]
     
     def __post_init__(self):
+        super().__post_init__()
         self.stat = SimpleHittingSplit(**self.stat)
 
-@dataclass(kw_only=True)
-class HittingSingleSeason(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingSingleSeason(Split):
     """
     A class to represent a hitting statsSingleSeason statistic
 
@@ -367,10 +381,11 @@ class HittingSingleSeason(Stat):
     stat: Union[SimpleHittingSplit, dict]
     
     def __post_init__(self):
+        super().__post_init__()
         self.stat = SimpleHittingSplit(**self.stat)
 
-@dataclass(kw_only=True)
-class HittingSeasonAdvanced(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingSeasonAdvanced(Split):
     """
     A class to represent a hitting seasonAdvanced statistic
 
@@ -383,10 +398,11 @@ class HittingSeasonAdvanced(Stat):
     stat: Union[AdvancedHittingSplit, dict]
 
     def __post_init__(self):
+        super().__post_init__()
         self.stat = AdvancedHittingSplit(**self.stat)
 
-@dataclass(kw_only=True)
-class HittingCareerAdvanced(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingCareerAdvanced(Split):
     """
     A class to represent a hitting season statistic
 
@@ -398,9 +414,10 @@ class HittingCareerAdvanced(Stat):
 
     def __post_init__(self):
         self.stat = AdvancedHittingSplit(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingYearByYear(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingYearByYear(Split):
     """
     A class to represent a hitting yearbyyear or yearByYearPlayoffs statistic
 
@@ -412,10 +429,11 @@ class HittingYearByYear(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingYearByYearPlayoffs(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingYearByYearPlayoffs(Split):
     """
     A class to represent a hitting yearByYearPlayoffs statistic
 
@@ -427,10 +445,11 @@ class HittingYearByYearPlayoffs(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass
-class OpponentsFacedHitting(Stat):
+@dataclass(kw_only=True, repr=False)
+class OpponentsFacedHitting(Split):
     """
     A class to represent a hitting opponentsFaced statistic
 
@@ -451,20 +470,24 @@ class OpponentsFacedHitting(Stat):
     fieldingteam: Union[Team, dict]
     pitcher: Union[Pitcher, dict]
 
-@dataclass
-class HittingSabermetrics(Stat):
+    def __post_init__(self):
+        super().__post_init__()
+
+@dataclass(kw_only=True, repr=False)
+class HittingSabermetrics(Split):
     """
     A class to represent a hitting sabermetric statistic
 
     """
     _stat = ['sabermetrics']
-    stat = Union[Sabermetrics, dict]
+    stat: Union[Sabermetrics, dict]
 
     def __post_init__(self):
         self.stat = Sabermetrics(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingGameLog(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingGameLog(Split):
     """
     A class to represent a gamelog stat for a hitter
 
@@ -498,17 +521,15 @@ class HittingGameLog(Stat):
     opponent: Union[Team, dict]
     _stat = ['gameLog']
     positionsplayed: Optional[List[Position]] = field(default_factory=list)
-    stat: Union[SimpleHittingSplit, dict]
+    stat: Union[SimpleHittingSplit, dict] = field(default_factory=dict)
     
     def __post_init__(self):
         if self.positionsplayed:
             self.positionsplayed = [Position(**position) for position in self.positionsplayed]
-        self.stat = [SimpleHittingSplit(**stat) for stat in self.stat]
+        self.stat = SimpleHittingSplit(**self.stat) if self.stat else self.stat
+        super().__post_init__()
 
-
-
-
-@dataclass
+@dataclass(kw_only=True, repr=False)
 class HittingPlay:
     """
     A class to represent a gamelog stat for a hitter
@@ -534,8 +555,12 @@ class HittingPlay:
         self.details = PlayDetails(**self.details)
         self.count = Count(**self.count)
 
-@dataclass(kw_only=True)
-class HittingPlayLog(Stat):
+    def __repr__(self) -> str:
+        kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None and value]
+        return "{}({})".format(type(self).__name__, ", ".join(kws))
+        
+@dataclass(kw_only=True, repr=False)
+class HittingPlayLog(Split):
     """
     A class to represent a gamelog stat for a hitter
 
@@ -570,10 +595,11 @@ class HittingPlayLog(Stat):
     _stat = ['playLog']
 
     def __post_init__(self):
-        self.stat = HittingPlay(**merge_keys(self.stat, 'play'))
+        self.stat = HittingPlay(**self.stat['play'])
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingPitchLog(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingPitchLog(Split):
     """
     A class to represent a gamelog stat for a hitter
 
@@ -610,11 +636,12 @@ class HittingPitchLog(Stat):
     playid: Optional[str] = None
 
     def __post_init__(self):
-        self.stat = HittingPlay(**merge_keys(self.stat, 'play'))
+        self.stat = HittingPlay(**self.stat['play'])
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingLastXGames(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingLastXGames(Split):
     """
     A class to represent a lastXGames statistic
 
@@ -626,10 +653,11 @@ class HittingLastXGames(Stat):
 
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingDateRange(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingDateRange(Split):
     """
     A class to represent a byDateRange statistic
 
@@ -641,10 +669,11 @@ class HittingDateRange(Stat):
 
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingDateRangeAdvanced(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingDateRangeAdvanced(Split):
     """
     A class to represent a byDateRangeAdvanced statistic
 
@@ -656,10 +685,11 @@ class HittingDateRangeAdvanced(Stat):
     
     def __post_init__(self):
         self.stat = AdvancedHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingDateRangeAdvancedByMonth(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingDateRangeAdvancedByMonth(Split):
     """
     A class to represent a byDateRangeAdvanced statistic
 
@@ -671,10 +701,11 @@ class HittingDateRangeAdvancedByMonth(Stat):
     
     def __post_init__(self):
         self.stat = AdvancedHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingByMonth(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingByMonth(Split):
     """
     A class to represent a byMonth hitting statistic
 
@@ -687,10 +718,11 @@ class HittingByMonth(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingByMonthPlayoffs(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingByMonthPlayoffs(Split):
     """
     A class to represent a yearByYear hitting statistic
 
@@ -705,10 +737,11 @@ class HittingByMonthPlayoffs(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
 
-@dataclass(kw_only=True)
-class HittingDayOfWeek(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingDayOfWeek(Split):
     """
     A class to represent a yearByYear hitting statistic
 
@@ -725,8 +758,8 @@ class HittingDayOfWeek(Stat):
         self.stat = SimpleHittingSplit(**self.stat)
 
 
-@dataclass(kw_only=True)
-class HittingDayOfWeekPlayoffs(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingDayOfWeekPlayoffs(Split):
     """
     A class to represent a yearByYear hitting statistic
 
@@ -741,9 +774,10 @@ class HittingDayOfWeekPlayoffs(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingExpectedStatistics(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingExpectedStatistics(Split):
     """
     A class to represent a excepted statistics statType: expectedStatistics.
     Attributes
@@ -757,9 +791,13 @@ class HittingExpectedStatistics(Stat):
     _stat = ['expectedStatistics']
     stat: Union[ExpectedStatistics, dict]
 
+    def __post_init__(self):
+        self.stat = ExpectedStatistics(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingVsTeam(Stat):
+
+@dataclass(kw_only=True, repr=False)
+class HittingVsTeam(Split):
     """
     A class to represent a vsTeam hitting statistic
 
@@ -777,9 +815,10 @@ class HittingVsTeam(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingVsTeamTotal(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingVsTeamTotal(Split):
     """
     A class to represent a vsTeamTotal hitting statistic
 
@@ -802,9 +841,10 @@ class HittingVsTeamTotal(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingVsTeam5Y(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingVsTeam5Y(Split):
     """
     A class to represent a vsTeam5Y hitting statistic
 
@@ -821,9 +861,10 @@ class HittingVsTeam5Y(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingVsPlayer(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingVsPlayer(Split):
     """
     A class to represent a yearByYear hitting statistic
 
@@ -848,9 +889,10 @@ class HittingVsPlayer(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingVsPlayerTotal(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingVsPlayerTotal(Split):
     """
     A class to represent a yearByYear hitting statistic
 
@@ -875,9 +917,10 @@ class HittingVsPlayerTotal(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
+        super().__post_init__()
 
-@dataclass(kw_only=True)
-class HittingVsPlayer5Y(Stat):
+@dataclass(kw_only=True, repr=False)
+class HittingVsPlayer5Y(Split):
     """
     A class to represent a yearByYear hitting statistic
 
@@ -902,84 +945,4 @@ class HittingVsPlayer5Y(Stat):
     
     def __post_init__(self):
         self.stat = SimpleHittingSplit(**self.stat)
-
-#
-# These dataclasses are for the game stats end point only
-# url: https://statsapi.mlb.com/api/v1/people/663728/stats/game/715757
-# The gamelog stats in this JSON have different keys set for their stat
-# and group. This breaks my logic of handling stat classes
-#
-
-@dataclass
-class HittingSplit:
-    """
-    A dataclass to handle a fielding gamelog stat for the game player stats endpoint
-
-    Attributes
-    ----------
-    gamesplayed : int
-    flyouts : int
-    groundouts : int
-    runs : int
-    doubles : int
-    triples : int
-    homeruns : int
-    strikeouts : int
-    baseonballs : int
-    intentionalwalks : int
-    hits : int
-    hitbypitch : int
-    atbats : int
-    caughtstealing : int
-    stolenbases : int
-    stolenbasepercentage : str
-    groundintodoubleplay : int
-    groundintotripleplay : int
-    plateappearances : int
-    totalbases : int
-    rbi : int
-    leftonbase : int
-    sacbunts : int
-    sacflies : int
-    catchersinterference : int
-    pickoffs : int
-    atbatsperhomerun : int
-    """
-    gamesplayed: int
-    flyouts: int
-    groundouts: int
-    runs: int
-    doubles: int
-    triples: int
-    homeruns: int
-    strikeouts: int
-    baseonballs: int
-    intentionalwalks: int
-    hits: int
-    hitbypitch: int
-    atbats: int
-    caughtstealing: int
-    stolenbases: int
-    stolenbasepercentage: str
-    groundintodoubleplay: int
-    groundintotripleplay: int
-    plateappearances: int
-    totalbases: int
-    rbi: int
-    leftonbase: int
-    sacbunts: int
-    sacflies: int
-    catchersinterference: int
-    pickoffs: int
-    atbatsperhomerun: int
-
-
-@dataclass
-class HittingGameLogStat:
-    type: str
-    group: str
-    stat: Union[HittingSplit, dict]
-    _stat = ['hitting']
-
-    def __post_init__(self):
-        self.stat = HittingSplit(**self.stat)
\ No newline at end of file
+        super().__post_init__()
